@@ -14,7 +14,7 @@ if __name__ == '__main__':
         print "       Please rename the existing one and restart install."
         sys.exit(-1)
     buildout_cfg = file('buildout.cfg', 'w')
-    buildout_cfg.write('[buildout]\nextends = profiles/base.cfg')
+    buildout_cfg.write('[buildout]\nextends = profiles/prod.cfg')
     buildout_cfg.close()
 
     # call boostrap.py
