@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008 Michael Howitz
+# Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: keyword.py 753 2008-10-24 18:11:39Z mac $
+# $Id: keyword.py 913 2009-01-02 12:47:38Z mac $
 
 import gocept.reference.interfaces
 import z3c.form.button
@@ -54,6 +54,6 @@ class EditForm(icemac.addressbook.browser.base.BaseEditForm):
 
 
 class DeleteForm(icemac.addressbook.browser.base.BaseDeleteForm):
-    label = _(u'Do you really want to delete this person?')
+    label = _(u'Do you really want to delete this keyword?')
     interface = icemac.addressbook.interfaces.IKeyword
     field_names = ('title', )
