@@ -1,11 +1,13 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008 Michael Howitz
+# Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: root.py 655 2008-09-20 19:08:13Z mac $
+# $Id: root.py 913 2009-01-02 12:47:38Z mac $
 
 import z3c.pagelet.browser
 import icemac.addressbook.interfaces
 
+from icemac.addressbook.i18n import MessageFactory as _
+
 
 class FrontPage(z3c.pagelet.browser.BrowserPagelet):
     """Pagelet for the front page."""
@@ -14,3 +16,11 @@ class FrontPage(z3c.pagelet.browser.BrowserPagelet):
         for value in self.context.values():
             if icemac.addressbook.interfaces.IAddressBook.providedBy(value):
                 yield value
+
+    def countEntries(self, address_book):
+        count = len(address_book)
+        if count == 1: # XXX use i18n instead!
+            entries = _(u'entry')
+        else:
+            entries = _(u'entries')
+        return "%s %s" % (count, entries)
