@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008 Michael Howitz
+# Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 775 2008-11-01 14:41:29Z mac $
+# $Id: tests.py 913 2009-01-02 12:47:38Z mac $
 
 import unittest
 import zope.interface.verify
@@ -14,9 +14,15 @@ import icemac.addressbook.tests
 class TestInterfaces(unittest.TestCase):
 
     def test_xls(self):
+        zope.interface.verify.verifyObject(
+            icemac.addressbook.export.interfaces.IExporter,
+            icemac.addressbook.export.xls.simple.XLSExport())
         zope.interface.verify.verifyObject(
             icemac.addressbook.export.interfaces.IExporter,
             icemac.addressbook.export.xls.simple.DefaultsExport())
+        zope.interface.verify.verifyObject(
+            icemac.addressbook.export.interfaces.IExporter,
+            icemac.addressbook.export.xls.simple.CompleteExport())
 
 
 def test_suite():
