@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008 Michael Howitz
+# Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: utils.py 695 2008-10-06 15:39:25Z mac $
+# $Id: utils.py 913 2009-01-02 12:47:38Z mac $
 
 import zope.app.container.interfaces
 import zope.event
@@ -28,6 +28,7 @@ def create_obj(class_, *args, **kw):
         setattr(obj, attrib, value)
     return obj
 
+
 create_obj_with_set_site = set_site(create_obj)
 
 
@@ -44,3 +45,11 @@ def create_and_add(parent, class_, *args, **kw):
 
 
 create_and_add_with_set_site = set_site(create_and_add)
+
+
+def iter_by_interface(container, interface):
+    "Iterate a container and return only objects providing the specified iface."
+    for obj in container.values():
+        if interface.providedBy(obj):
+            yield obj
+
