@@ -13,7 +13,7 @@
 ##############################################################################
 """Form and Widget Framework Interfaces
 
-$Id: interfaces.py 90534 2008-08-28 09:07:37Z icemac $
+$Id: interfaces.py 93891 2008-12-11 09:11:57Z icemac $
 """
 __docformat__ = "reStructuredText"
 
@@ -25,11 +25,15 @@ from zope.publisher.interfaces.browser import IBrowserRequest
 
 from z3c.form.i18n import MessageFactory as _
 
-
 INPUT_MODE = 'input'
 DISPLAY_MODE = 'display'
 HIDDEN_MODE = 'hidden'
 
+class NOT_CHANGED(str):
+    def __repr__(self):
+        return '<NOT_CHANGED>'
+NOT_CHANGED = NOT_CHANGED()
+
 class NOVALUE(object):
     def __repr__(self):
         return '<NOVALUE>'
@@ -154,6 +158,10 @@ class IErrorViewSnippet(zope.interface.Interface):
     def render():
         """Render view."""
 
+class IMultipleErrors(zope.interface.Interface):
+    """An error that contains many errors"""
+
+    errors = zope.interface.Attribute("List of errors")
 
 # ----[ Fields ]--------------------------------------------------------------
 
@@ -185,11 +193,11 @@ class IField(zope.interface.Interface):
         description=_('The interface from which the field is coming.'),
         required=True)
 
-    dataProvider = zope.schema.Field(
-        title=_('Data Provider'),
-        description=_('The component providing the data of the field for '
-                      'the widget.'),
-        required=True)
+    ignoreContext = zope.schema.Bool(
+        title=_('Ignore Context'),
+        description=_('A flag, when set, forces the widget not to look at '
+                      'the context for a value.'),
+        required=False)
 
     widgetFactory = zope.schema.Field(
         title=_('Widget Factory'),
@@ -331,6 +339,30 @@ class IBoolTerms(ITerms):
         required=False)
 
 
+# ----[ Object factory ]-----------------------------------------------------
+
+class IObjectFactory(zope.interface.Interface):
+    """Factory that will instatiate our objects for ObjectWidget
+    It could also pre-populate properties as it gets the values extracted
+    from the form passed in ``value``
+    """
+
+    def __call__(value):
+        """return a default object created to be populated
+        """
+
+
+# ----[ Subform factory ]-----------------------------------------------------
+
+class ISubformFactory(zope.interface.Interface):
+    """Factory that will instatiate our subforms for ObjectWidget
+    """
+
+    def __call__():
+        """return a default object created to be populated
+        """
+
+
 # ----[ Widgets ]------------------------------------------------------------
 
 class IWidget(ILocation):
@@ -386,7 +418,7 @@ class IWidget(ILocation):
         default=False,
         required=False)
 
-    def extract(default=NOVALUE):
+    def extract(default=NOVALUE, setErrors=True):
         """Extract the string value(s) of the widget from the form.
 
         The return value may be any Python construct, but is typically a
@@ -396,10 +428,12 @@ class IWidget(ILocation):
 
         If an error occurs during the extraction, the default value should be
         returned. Since this should never happen, if the widget is properly
-        designed and used, it is okay to not raise an error here, since we do
+        designed and used, it is okay to NOT raise an error here, since we do
         not want to crash the system during an inproper request.
 
         If there is no value to extract, the default is to be returned.
+
+        setErrors: needs to be passed on to possible sub-widgets
         """
 
     def update():
@@ -518,6 +552,8 @@ class IFileWidget(ITextWidget):
 class IPasswordWidget(ITextWidget):
     """Password widget."""
 
+class IObjectWidget(IWidget):
+    """Object widget."""
 
 class IWidgets(IManager):
     """A widget manager"""
@@ -562,8 +598,11 @@ class IWidgets(IManager):
     def update():
         """Setup widgets."""
 
-    def extract():
+    def extract(setErrors=True):
         """Extract the values from the widgets and validate them.
+
+        setErrors: decides whether to set errors on self and on the widgets
+                   also needs to be passed on to sub-widgets
         """
 
 
@@ -823,8 +862,10 @@ class IForm(zope.interface.Interface):
         mainly meant to be a hook for subclasses.
         '''
 
-    def extractData():
-        '''Extract the data of the form.'''
+    def extractData(setErrors=True):
+        '''Extract the data of the form.
+
+        setErrors: needs to be passed to extract() and to sub-widgets'''
 
     def update():
         '''Update the form.'''
